@@ -17,9 +17,13 @@ from functools import wraps
 import requests
 from flask import redirect, request, json
 
-__version__ = '1.1.1'
+__version__ = '2.0.0'
+
+_logger = logging.getLogger(__name__)
+# Add NullHandler to prevent logging warnings on startup
+null_handler = logging.NullHandler()
+_logger.addHandler(null_handler)
 
-logger = logging.getLogger(__name__)
 
 
 class GitHubError(Exception):
@@ -57,7 +61,6 @@ class GitHub(object):
     def init_app(self, app):
         self.client_id = app.config['GITHUB_CLIENT_ID']
         self.client_secret = app.config['GITHUB_CLIENT_SECRET']
-        self.callback_url = app.config['GITHUB_CALLBACK_URL']
         self.base_url = app.config.get('GITHUB_BASE_URL', self.BASE_URL)
         self.auth_url = app.config.get('GITHUB_AUTH_URL', self.BASE_AUTH_URL)
         self.session = requests.session()
@@ -74,21 +77,20 @@ class GitHub(object):
     def get_access_token(self):
         raise NotImplementedError
 
-    def authorize(self, scope=None):
+    def authorize(self, scope=None, redirect_uri=None):
         """
         Redirect to GitHub and request access to a user's data.
 
         """
-        logger.debug("Called authorize()")
-        params = {
-            'client_id': self.client_id,
-            'redirect_uri': self.callback_url,
-        }
-        if scope is not None:
+        _logger.debug("Called authorize()")
+        params = {'client_id': self.client_id}
+        if scope:
             params['scope'] = scope
+        if redirect_uri:
+            params['redirect_uri'] = redirect_uri
 
         url = self.auth_url + 'authorize?' + urlencode(params)
-        logger.debug("Redirecting to %s", url)
+        _logger.debug("Redirecting to %s", url)
         return redirect(url)
 
     def authorized_handler(self, f):
@@ -115,18 +117,18 @@ class GitHub(object):
         authenticate requests to GitHub.
 
         """
-        logger.debug("Handling response from GitHub")
+        _logger.debug("Handling response from GitHub")
         params = {
             'code': request.args.get('code'),
             'client_id': self.client_id,
             'client_secret': self.client_secret
         }
         url = self.auth_url + 'access_token'
-        logger.debug("POSTing to %s", url)
-        logger.debug(params)
+        _logger.debug("POSTing to %s", url)
+        _logger.debug(params)
         response = self.session.post(url, data=params)
         data = parse_qs(response.content)
-        logger.debug("response.content = %s", data)
+        _logger.debug("response.content = %s", data)
         for k, v in data.items():
             if len(v) == 1:
                 data[k] = v[0]
